// Copyright (C) 2008, 2009 by Florent Lamiraux, Thomas Moulard, CNRS.
//
// This file is part of the hpp-walkfootplanner.
//
// This software is provided "as is" without warranty of any kind,
// either expressed or implied, including but not limited to the
// implied warranties of fitness for a particular purpose.
//
// See the COPYING file for more information.

#ifndef HPPWALKFOOTPLANNER_FOOTSTEP_SEQUENCE_HH
# define HPPWALKFOOTPLANNER_FOOTSTEP_SEQUENCE_HH
# include <iosfwd>
# include <vector>
# include <boost/numeric/ublas/vector.hpp>
# include <hpp/walkfootplanner/config.hh>
# include <hpp/walkfootplanner/fwd.hh>

namespace hpp
{
  namespace walkFootPlanner
  {
    typedef boost::numeric::ublas::bounded_vector<double, 3> footStep_t;
    typedef std::vector<footStep_t> footSteps_t;

    class HPP_WALKFOOTPLANNER_DLLAPI FootStepSequence
    {
    public:
      explicit FootStepSequence (bool leftFootFirst = true);
      ~FootStepSequence ();

      const footStep_t& initialFootStep () const;
      footStep_t& initialFootStep ();

      const bool& leftFootFirst () const;
      bool& leftFootFirst ();

      const footSteps_t& footSteps () const;
      footSteps_t& footSteps ();

      std::ostream& print (std::ostream& o) const;
    private:
      footStep_t initialFootStep_;
      bool leftFootFirst_;
      footSteps_t footSteps_;
    };

    HPP_WALKFOOTPLANNER_DLLAPI std::ostream&
    operator<< (std::ostream& o, const FootStepSequence& fss);

  } // end of namespace walkFootPlanner.
} // end of namespace hpp.

#endif //! HPPWALKFOOTPLANNER_FOOTSTEP_SEQUENCE_HH
