// Copyright (C) 2008, 2009 by Florent Lamiraux, Thomas Moulard, CNRS.
//
// This file is part of the hpp-walkfootplanner.
//
// This software is provided "as is" without warranty of any kind,
// either expressed or implied, including but not limited to the
// implied warranties of fitness for a particular purpose.
//
// See the COPYING file for more information.

#include <boost/foreach.hpp>

#include "hpp/util/indent.hh"
#include "hpp/walkfootplanner/io.hh"
#include "hpp/walkfootplanner/footstep-sequence.hh"


namespace hpp
{
  namespace walkFootPlanner
  {
    FootStepSequence::FootStepSequence (bool leftFootFirst)
      : initialFootStep_ (),
	leftFootFirst_ (leftFootFirst),
	footSteps_ ()
    {
      initialFootStep_.clear ();
    }

    FootStepSequence::~FootStepSequence ()
    {}


    const footStep_t&
    FootStepSequence::initialFootStep () const
    {
      return initialFootStep_;
    }

    footStep_t&
    FootStepSequence::initialFootStep ()
    {
      return initialFootStep_;
    }

    const bool&
    FootStepSequence::leftFootFirst () const
    {
      return leftFootFirst_;
    }

    bool&
    FootStepSequence::leftFootFirst ()
    {
      return leftFootFirst_;
    }


    const footSteps_t&
    FootStepSequence::footSteps () const
    {
      return footSteps_;
    }

    footSteps_t&
    FootStepSequence::footSteps ()
    {
      return footSteps_;
    }

    std::ostream&
    FootStepSequence::print (std::ostream& o) const
    {
      o << (leftFootFirst_ ? "Left" : "Right") << " foot first" << iendl
	<< "Initial footstep (initial position in global frame): "
	<< initialFootStep_ << iendl
	<< "Footsteps:" << incindent << iendl;

      BOOST_FOREACH (const footStep_t& fs, footSteps_)
	o << fs << iendl;
      o << decindent;
      return o;
    }


    std::ostream&
    operator<< (std::ostream& o, const FootStepSequence& fss)
    {
      return fss.print (o);
    }

  } // end of namespace walkFootPlanner.
} // end of namespace hpp.
